@@ -1,4 +1,5 @@
 import re
+import hashlib
 from typing import TYPE_CHECKING, Union
 
 from jinja2 import StrictUndefined, Template
@@ -8,6 +9,7 @@ from metrics_layer.core.exceptions import (
     QueryError,
 )
 
+from .definitions import Definitions
 from .base import MetricsLayerBase, SQLReplacement
 from .field import Field, ZenlyticFieldType
 from .join import ZenlyticJoinRelationship, ZenlyticJoinType
@@ -56,6 +58,9 @@ class View(MetricsLayerBase, SQLReplacement):
         self.validate(definition)
         super().__init__(definition)
 
+    def id(self):
+        return self.name
+
     @property
     def sql_table_name(self):
         if "sql_table_name" in self._definition:
@@ -158,8 +163,9 @@ class View(MetricsLayerBase, SQLReplacement):
             elif "model" in self._definition:
                 model: Model = self._definition["model"]
                 return model
-        except AccessDeniedOrDoesNotExistException:
-            raise QueryError(f"View {self.name} is missing the required model_name property")
+        except AccessDeniedOrDoesNotExistException as e:
+            e.message = str(e) + f" in view {self.name}"
+            raise e
 
     @property
     def week_start_day(self):
@@ -169,6 +175,17 @@ class View(MetricsLayerBase, SQLReplacement):
                 return model.week_start_day.lower()
         return "monday"
 
+    def sql_hash(self):
+        if self.derived_table_sql:
+            sql_definition = self.derived_table_sql
+        else:
+            sql_definition = self.sql_table_name
+
+        if sql_definition is not None:
+            result = hashlib.md5(sql_definition.encode("utf-8"))  # nosec
+            return result.hexdigest()
+        return None
+
     def sql_replacement_func(self, sql: str):
         return self.jinja_replacements(sql, {"user_attributes": self.project._user})
 
@@ -237,7 +254,7 @@ class View(MetricsLayerBase, SQLReplacement):
             )
             if self.model is None:
                 return [self._error(self._definition.get("model_name"), model_error)]
-        except QueryError:
+        except AccessDeniedOrDoesNotExistException:
             return [self._error(self._definition.get("model_name"), model_error)]
 
         if not self.valid_name(self.name):
