@@ -54,6 +54,28 @@ class ProjectReaderBase:
     def dbt_folder(self):
         return self.repo.dbt_path if self.repo.dbt_path else self.repo.folder
 
+    def get_folders(self, key: str, default: str = None, raise_errors: bool = True):
+        if not self.zenlytic_project:
+            return []
+
+        if key in self.zenlytic_project:
+            return [self._abs_path(p) for p in self.zenlytic_project[key]]
+        elif raise_errors:
+            raise KeyError(
+                f"Missing required key '{key}' in zenlytic_project.yml \n"
+                "Learn more about setting these keys here: https://docs.zenlytic.com"
+            )
+        return []
+
+    def _abs_path(self, path: str):
+        if not os.path.isabs(path):
+            path = os.path.join(self.repo.folder, path)
+        return path
+
+    def search_for_yaml_files(self, folders: list):
+        file_names = self.repo.search("*.yml", folders) + self.repo.search("*.yaml", folders)
+        return list(set(file_names))
+
     @staticmethod
     def read_yaml_if_exists(file_path: str):
         if os.path.exists(file_path):
@@ -68,11 +90,16 @@ class ProjectReaderBase:
             yaml_dict = yaml.load(f)
         return yaml_dict
 
+    @staticmethod
+    def repr_str(representer, data):
+        return representer.represent_str(str(data))
+
     @staticmethod
     def dump_yaml_file(data: dict, path: str):
+        yaml = ruamel.yaml.YAML(typ="rt")
         filtered_data = {k: v for k, v in data.items() if not k.startswith("_")}
         with open(path, "w") as f:
-            ruamel.yaml.dump(filtered_data, f, Dumper=ruamel.yaml.RoundTripDumper)
+            yaml.dump(filtered_data, f)
 
     def load(self) -> None:
         raise NotImplementedError()
