@@ -16,6 +16,7 @@ class SingleSQLQueryResolver:
         where: str = None,  # Either a list of json or a string
         having: str = None,  # Either a list of json or a string
         order_by: str = None,  # Either a list of json or a string
+        topic=None,
         model=None,
         project=None,
         **kwargs,
@@ -25,7 +26,6 @@ class SingleSQLQueryResolver:
         self.has_cumulative_metric = False
         self.verbose = kwargs.get("verbose", False)
         self.select_raw_sql = kwargs.get("select_raw_sql", [])
-        self.explore_name = kwargs.get("explore_name")
         self.suppress_warnings = kwargs.get("suppress_warnings", False)
         self.limit = kwargs.get("limit")
         self.return_pypika_query = kwargs.get("return_pypika_query")
@@ -34,8 +34,9 @@ class SingleSQLQueryResolver:
         self.metrics = metrics
         self.dimensions = dimensions
         self.funnel, self.is_funnel_query = self.parse_funnel(funnel)
-        self.parse_field_names(where, having, order_by)
+        self.topic = topic
         self.model = model
+        self.parse_field_names(where, having, order_by)
         self.nesting_depth = kwargs.get("nesting_depth", 0)
         self.query_type = kwargs.get("query_type")
         if self.query_type is None:
@@ -51,6 +52,7 @@ class SingleSQLQueryResolver:
             no_group_by=self.no_group_by,
             query_type=self.query_type,
             field_lookup=self.field_lookup,
+            topic=self.topic,
             model=self.model,
             project=self.project,
         )
@@ -226,8 +228,7 @@ class SingleSQLQueryResolver:
     def _is_literal(clause):
         return isinstance(clause, str) or clause is None
 
-    @staticmethod
-    def parse_identifiers_from_dicts(conditions: list):
+    def parse_identifiers_from_dicts(self, conditions: list):
         flattened_conditions = SingleSQLQueryResolver.flatten_filters(conditions)
         try:
             field_names = []
@@ -236,6 +237,10 @@ class SingleSQLQueryResolver:
                     field_names.append(cond["group_by"])
                 else:
                     field_names.append(cond["field"])
+                if "value" in cond and isinstance(cond["value"], str):
+                    mapped_field = self.project.get_mapped_field(cond["value"], model=self.model)
+                    if mapped_field:
+                        field_names.append(cond["value"])
             return field_names
         except KeyError:
             for cond in conditions:
